@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -129,14 +129,14 @@ void SieveAction::unknownTag(const QStringRef &tag, QString &error)
     error += i18n("An unknown tag \"%1\" was found during parsing action \"%2\".", *tag.string(), name()) + QLatin1Char('\n');
 }
 
-void SieveAction::unknowTagValue(const QString &tagValue, QString &error)
+void SieveAction::unknownTagValue(const QString &tagValue, QString &error)
 {
     error += i18n("An unknown tag value \"%1\" was found during parsing action \"%2\".", tagValue, name()) + QLatin1Char('\n');
 }
 
-void SieveAction::tooManyArgument(const QStringRef &tagName, int index, int maxValue, QString &error)
+void SieveAction::tooManyArguments(const QStringRef &tagName, int index, int maxValue, QString &error)
 {
-    error += i18n("Too many argument found for \"%1\", max value is %2, number of value found %3 for %4", name(), maxValue, index, *tagName.string()) + QLatin1Char('\n');
+    error += i18n("Too many arguments found for \"%1\", max value is %2, number of value found %3 for %4", name(), maxValue, index, *tagName.string()) + QLatin1Char('\n');
 }
 
 void SieveAction::serverDoesNotSupportFeatures(const QString &feature, QString &error)
