@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,7 +27,7 @@ class MultiLineEdit : public KPIMTextEdit::PlainTextEditor
     Q_OBJECT
 public:
     explicit MultiLineEdit(QWidget *parent = nullptr);
-    ~MultiLineEdit();
+    ~MultiLineEdit() override;
 
 Q_SIGNALS:
     void valueChanged();
