@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,7 +36,7 @@ using namespace KSieveUi;
 SelectFlagsListDialog::SelectFlagsListDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Flags"));
+    setWindowTitle(i18nc("@title:window", "Flags"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mListWidget = new SelectFlagsListWidget(this);
     mainLayout->addWidget(mListWidget);
